@@ -556,9 +556,9 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     
     # tar it up
     TAR_NAME = "app-utils"
-    CONFIG_DIR = APP_UTILS_DIR + "/config"
-    ENV_DIR = APP_UTILS_DIR + "/environments"
-    KEY_DIR = (APP_UTILS_DIR + "/keys/" + ENVIRONMENT) if (keys in TRUTH_VALUES) else ""
+    CONFIG_DIR = "config/"
+    ENV_DIR = "environments/"
+    KEY_DIR = ("keys/" + ENVIRONMENT) if (keys in TRUTH_VALUES) else ""
 
     DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR
     print(DIRS_TO_TAR)
@@ -568,7 +568,7 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     # and move the tarball to the destination and expand it
     # set the upload path to the home directory
     UPLOAD_CODE_PATH = "$HOME/" + appname 
-    cmd = "mkdir -p " + UPLOAD_CODE_PATH
+    cmd = "mkdir -p " + UPLOAD_CODE_PATH + "/" + APP_UTILS_DIR
     sudo(cmd)
     with cd('%s' % UPLOAD_CODE_PATH):
         put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME, use_sudo=True)
